# Installation

## Requirements

- Python 3.12 or higher

## Install from PyPI

```bash
pip install haiway
```

## Optional Dependencies

You may choose to install haiway including optional support for OpenTelemetry.

### OpenTelemetry Support

For distributed tracing and observability:

```bash
pip install haiway[opentelemetry]
```

For httpx implementation of http client:

```bash
pip install haiway[httpx]
```

Now you're ready to continue with the [Quick Start](quickstart.md) guide!
